'use strict';
const fs = require('fs');
const path = require('path');
const bytes = require('bytes');
const events = require('events');
const Stream = require('stream');

class DirAnalyzer {
    constructor(dir, ignoreArray) {
        !dir ? dir = '/' : null;
        !ignoreArray ? ignoreArray = null : null;

        this.dirIgnore = ignoreArray.map(i => {
            return path.resolve(i)
        });

        this.fileCounter = 0;
        this.dirCounter = 0;
        this.toScan = [dir];
        this.err = [];
        this.run = true;

        this.events = new events.EventEmitter();
        this.stream = new Stream.Readable({ objectMode: true });
        this.stream.setEncoding('utf8');
        this.stream._read = () => {}
    }

    start() {
        this.events.on('loop-done', () => {
            this.toScan.splice(0, 1);
            if (this.toScan.length == 0) {
                this.run = false;
                this.stream.push(null);
                this.events.emit('scan-done')
            } else {
                this.scanFiles(this.toScan[0])
            }
        });
        this.scanFiles(this.toScan[0])
    }

    scanFiles(dir) {
        this.dirCounter++;
        fs.readdir(dir, (err, list) => {
            let resolvedDir = path.resolve(dir);
            let dirCheck = this.dirIgnore.filter(i => {
                return i.toLowerCase() == resolvedDir.toLowerCase()
            });
            if (dirCheck.length == 0) {

                this.err.push(err);
                if (typeof list != 'undefined') {

                    list.forEach(file => {
                        this.fileCounter++;
                        let filePath = path.resolve(`${dir}/${file}`);
                        let fileObj = path.parse(filePath);
                        try {
                            var stat = fs.statSync(filePath)
                        } catch (e) {
                            var statErr = e;
                        }
                        if (!statErr) {

                            // Standard props
                            fileObj.fullPath = filePath;
                            fileObj.atime = stat.atime;
                            fileObj.mtime = stat.mtime;
                            fileObj.ctime = stat.ctime;
                            fileObj.dirSplit = fileObj.dir.split(path.sep)
                            fileObj.depth = fileObj.dirSplit.length

                            if (!stat.isDirectory()) {
                                fileObj.bytes = stat.size;
                                fileObj.size = bytes(stat.size);
                                fileObj.type = 'file';
                                this.stream.push(fileObj, 'utf8');
                            } else {
                                fileObj.bytes = 0;
                                fileObj.size = 0;
                                fileObj.type = 'folder';
                                this.stream.push(fileObj, 'utf8');
                                this.toScan.push(filePath)
                            }
                        }
                    })
                }
            }
            this.events.emit('loop-done')
        })
    }
}

module.exports = DirAnalyzer;