# dir-analyzer
A recursive directory scanner/analyzer implemented in Node.js using streams, producing a JSON object for each file scanned.

### Install
```javascript
npm install dir-analyzer
```

### Output Example
```
{ 
  root: 'C:\\',
  dir: 'C:\\some-directory,                       // Directory of File
  base: 'package.json',                           // Full file name
  ext: '.json',                                   // Extension if it exists
  name: 'package',                                // Name without ext
  fullPath: 'C:\\some-directory\\package.json',   // Absolute file path
  atime: '2016-07-11T22:58:34.176Z',              // Access time
  mtime: '2016-07-11T22:58:34.396Z',              // Modify time        
  ctime: '2016-07-11T22:58:34.509Z',              // Change time
  dirSplit: ['c:','some-directory'],              // Directory split into an array
  depth: 2,                                       // Depth of current file
  bytes: 3085,                                    // Size in bytes
  size: '3.01kB',                                 // Size in human readable
  type: 'file'                                    // Type (file or folder)
}
```

### Example Usage
```javascript
'use strict';
const DirAnalyzer = require('dir-analyzer');
const fs = require('fs');

// Declare my write stream.
let myFlatDb = fs.createWriteStream('./data/output.json');

// Initialize your scan object.
// Takes a directory to scan argument, and an array of directories to ignore arguement.
const scan = new DirAnalyzer('/', ['/windows']);

// Read the data coming in from the scan.
scan.stream.on('data', data => {
    console.log(data)
});

// Pipe the data.
scan.stream.pipe(myFlatDb);

// Perform a function when the scan is complete.
scan.stream.on('end', () => {
    console.log('Scan is done!');
});

// Start your scan.
scan.start();

```


#### License

MIT License Copyright (c) 2016 Elias Hussary

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.